==> gallery_1.5.orig.tar.gz: gallery-1.5.orig/locale/pl_PL/pl_PL-nls.php <==
<?php
/*
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2005 Bharat Mediratta
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Id: pl_PL-nls.php,v 1.8.2.3 2005/03/23 08:57:49 cryptographite Exp $
 *
 * Version: 1.5
 */
/**
 * NLS (National Language System) array.
 *
 * The basic idea and values was taken from then Horde Framework (http://horde.org)
 * The original filename was horde/config/nls.php.dist.
 * The modifications to fit it for Gallery were made by Jens Tkotz 
 * (jens@peino.de)
 *
 */


/**
 ** Native languagename
 **/
	$nls['language']['pl_PL'] = 		'Polski';

/**
 ** Alias for languages with different browser and gettext codes
 **/

	$nls['alias']['pl'] = 			'pl_PL';

/**
 ** Alias for languages which we substitte or send by NUKE
 **/
	$nls['alias']['polish'] =		'pl_PL' ;
	$nls['alias']['pl_PL.ISO8859-2'] =	'pl_PL' ;

/**
 ** Charset
 **
 **/	
	
	$nls['charset']['pl_PL'] = 		'ISO-8859-2';
/**
 ** phpNuke
 **/
 
	$nls['phpnuke']['pl_PL'] = 		'polish';
?>

==> gallery_1.5.1.orig.tar.gz: gallery-1.5.1.orig/locale/pl_PL/pl_PL-nls.php <==
<?php
/*
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2005 Bharat Mediratta
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * $Id: pl_PL-nls.php,v 1.12.2.2 2005/09/12 22:41:05 dmolavi Exp $
  */
 
/**
 * @version	1.5.1
 * @package	Languagepack
 * @subpackage	Polish
 */

/**
 * NLS (National Language System) array.
 *
 * The basic idea and values was taken from then Horde Framework (http://horde.org)
 * The original filename was horde/config/nls.php.dist.
 * The modifications to fit it for Gallery were made by Jens Tkotz.
 * (jens@peino.de)
 */

/**
 * Native languagename
 */
	$nls['language']['pl_PL'] = 		'Polski';

/**
 * Aliases for languages with different browser and gettext codes
 */
	$nls['alias']['pl'] = 			'pl_PL';

/**
 * Aliases for languages which we substitte or send by NUKE, GeekLog or Mambo
 */
	$nls['alias']['polish'] =		'pl_PL' ;
	$nls['alias']['pl_PL.ISO8859-2'] =	'pl_PL' ;

/**
 ** Charset
 *
 */
	$nls['charset']['pl_PL'] = 		'ISO-8859-2';
/**
 * phpNuke
 */
	$nls['phpnuke']['pl_PL'] = 		'polish';

?>
